@@ -12,6 +12,10 @@
 
 /* define the extra mib modules that are supported */
 #define NETSNMP_INCLUDE_HOST_RESOURCES
-#ifdef NETSNMP_ENABLE_MFD_REWRITES
 #define NETSNMP_INCLUDE_IFTABLE_REWRITES
-#endif
+
+#undef INP_NEXT_SYMBOL
+#define INP_NEXT_SYMBOL inp_next
+#undef INP_PREV_SYMBOL
+#define INP_PREV_SYMBOL inp_prev
+
